@@ -1,7 +1,6 @@
 LSD.test <-
-function (y, trt, DFerror, MSerror, alpha = 0.05, p.adj = c("none","holm","hommel",
-                                                              "hochberg", "bonferroni", "BH", "BY", "fdr"), group = TRUE,
-            main = NULL,console=FALSE)
+  function (y, trt, DFerror, MSerror, alpha = 0.05, p.adj = c("none","holm","hommel",
+  "hochberg", "bonferroni", "BH", "BY", "fdr"), group = TRUE, main = NULL,console=FALSE)
   {
     p.adj <- match.arg(p.adj)
     clase <- c("aov", "lm")
@@ -33,17 +32,22 @@ function (y, trt, DFerror, MSerror, alpha = 0.05, p.adj = c("none","holm","homme
     junto <- subset(data.frame(y, trt), is.na(y) == FALSE)
     Mean<-mean(junto[,1])
     CV<-sqrt(MSerror)*100/Mean
+    medians<-tapply.stat(junto[,1],junto[,2],stat="median")
+    for(i in c(1,5,2:4)) {
+      x <- tapply.stat(junto[,1],junto[,2],function(x)quantile(x)[i])
+      medians<-cbind(medians,x[,2])
+    }
+    medians<-medians[,3:7]
+    names(medians)<-c("Min","Max","Q25","Q50","Q75")    
     means <- tapply.stat(junto[, 1], junto[, 2], stat = "mean")
     sds <- tapply.stat(junto[, 1], junto[, 2], stat = "sd")
     nn <- tapply.stat(junto[, 1], junto[, 2], stat = "length")
-    mi<-tapply.stat(junto[,1],junto[,2],stat="min") # change
-    ma<-tapply.stat(junto[,1],junto[,2],stat="max") # change
     std.err <- sqrt(MSerror)/sqrt(nn[, 2]) # change sds[,2]
     Tprob <- qt(1 - alpha/2, DFerror)
     LCL <- means[, 2] - Tprob * std.err
     UCL <- means[, 2] + Tprob * std.err
     means <- data.frame(means, std=sds[,2], r = nn[, 2],
-                        LCL, UCL,Min=mi[,2],Max=ma[,2])
+                        LCL, UCL,medians)
     names(means)[1:2] <- c(name.t, name.y)
     ntr <- nrow(means)
     nk <- choose(ntr, 2)
@@ -71,24 +75,21 @@ function (y, trt, DFerror, MSerror, alpha = 0.05, p.adj = c("none","holm","homme
       cat("\nMean Square Error: ", MSerror, "\n\n")
       cat(paste(name.t, ",", sep = ""), " means and individual (",
           (1 - alpha) * 100, "%) CI\n\n")
-      print(data.frame(row.names = means[, 1], means[, -1]))
+      print(data.frame(row.names = means[, 1], means[, 2:8]))
       cat("\nAlpha:", alpha, "; DF Error:", DFerror)
       cat("\nCritical Value of t:", Tprob, "\n")
     }
-    
-    if (group) {
-      if (p.adj == "none")Tprob <- qt(1 - alpha/2, DFerror)
-      if (length(nr) == 1 & (p.adj =="bonferroni" | p.adj =="none")) {
-        LSD <- Tprob * sqrt(2 * MSerror/nr)
-        if(console)cat("\nLeast Significant Difference", LSD)
-        statistics<-data.frame(Mean=Mean,CV=CV,MSerror=MSerror,LSD=LSD)
-      }}
-    if (!group | length(nr) != 1) {
-      if(console)cat("\nMinimum difference changes for each comparison\n")
-      statistics<-data.frame(Mean=Mean,CV=CV,MSerror=MSerror)
-    }
-    if(console){cat("\nMeans with the same letter are not significantly different\n")
-      cat("\n\nGroups, Treatments and means\n")}	
+    statistics<-data.frame(MSerror=MSerror,Df=DFerror,Mean=Mean,CV=CV)     
+if (length(nr) == 1)  LSD <- Tprob * sqrt(2 * MSerror/nr)
+if ( group & length(nr) == 1 & console) {
+ if(p.adj=="none") cat("\nleast Significant Difference:",LSD,"\n")
+ else cat("\nMinimum Significant Difference:",LSD,"\n")
+}
+if ( group & length(nr) != 1 & console) 
+cat("\nGroups according to probability of means differences and alpha level(",alpha,")\n")
+
+if ( length(nr) == 1 & p.adj=="none") statistics<-data.frame(statistics, t.value=Tprob,LSD=LSD) 
+if ( length(nr) == 1 & p.adj!="none") statistics<-data.frame(statistics, t.value=Tprob,MSD=LSD)    
     LSD=" "
     comb <- utils::combn(ntr, 2)
     nn <- ncol(comb)
@@ -99,13 +100,9 @@ function (y, trt, DFerror, MSerror, alpha = 0.05, p.adj = c("none","holm","homme
     for (k in 1:nn) {
       i <- comb[1, k]
       j <- comb[2, k]
-      #            if (means[i, 2] < means[j, 2]) {
-      #                comb[1, k] <- j
-      #                comb[2, k] <- i
-      #            }
+
       dif[k] <-means[i, 2] - means[j, 2]
-      sdtdif[k] <- sqrt(MSerror * (1/means[i, 4] + 1/means[j,
-                                                           4]))
+      sdtdif[k] <- sqrt(MSerror * (1/means[i, 4] + 1/means[j,4]))
       pvalue[k] <- 2 * (1 - pt(abs(dif[k])/sdtdif[k], DFerror))
     }
     if (p.adj != "none")
@@ -125,10 +122,10 @@ function (y, trt, DFerror, MSerror, alpha = 0.05, p.adj = c("none","holm","homme
     tr.j <- means[comb[2, ], 1]
     LCL <- dif - Tprob * sdtdif
     UCL <- dif + Tprob * sdtdif
-    comparison <- data.frame(Difference = dif, pvalue = pvalue, "sig."=sig, LCL, UCL)
+    comparison <- data.frame(difference = dif, pvalue = pvalue, "signif."=sig, LCL, UCL)
     if (p.adj !="bonferroni" & p.adj !="none"){
-    comparison<-comparison[,1:3]
-    statistics<-data.frame(Mean=Mean,CV=CV,MSerror=MSerror)
+      comparison<-comparison[,1:3]
+  #    statistics<-statistics[,1:4]
     }
     rownames(comparison) <- paste(tr.i, tr.j, sep = " - ")
     if (!group) {
@@ -137,7 +134,7 @@ function (y, trt, DFerror, MSerror, alpha = 0.05, p.adj = c("none","holm","homme
         print(comparison)
       }
       groups <- NULL
-      statistics<-data.frame(Mean=Mean,CV=CV,MSerror=MSerror)
+   #   statistics<-statistics[,1:4]
     }
     if (group) {
       comparison=NULL
@@ -153,17 +150,19 @@ function (y, trt, DFerror, MSerror, alpha = 0.05, p.adj = c("none","holm","homme
         }
       }
       groups <- orderPvalue(means[, 1], means[, 2],alpha, Q,console)
-      groups<-groups[,1:3]
+      names(groups)[1]<-name.y
+      if(console) {
+        cat("\nTreatments with the same letter are not significantly different.\n\n")
+        print(groups)  
+      }   
     }
-    test<-"Fisher-LSD"
-    if(p.adj!="none")test<-p.adj
-    parameters<-data.frame(Df=DFerror,ntr = ntr, t.value=Tprob,alpha=alpha,test=test,name.t=name.t)
-    if(p.adj!="none") names(parameters)[3]<-p.adj
+    parameters<-data.frame(test="Fisher-LSD",p.ajusted=p.adj,name.t=name.t,ntr = ntr,alpha=alpha)
     rownames(parameters)<-" "
     rownames(statistics)<-" "
     rownames(means)<-means[,1]
     means<-means[,-1]
     output<-list(statistics=statistics,parameters=parameters, 
                  means=means,comparison=comparison,groups=groups)
+    class(output)<-"group"
     invisible(output)
   }
